@@ -116,7 +116,7 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html)
     """
 
@@ -124,36 +124,38 @@ class ElasticsearchServiceClient:
     exceptions: Exceptions
 
     def accept_inbound_cross_cluster_search_connection(
-        self, CrossClusterSearchConnectionId: str
+        self, *, CrossClusterSearchConnectionId: str
     ) -> AcceptInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#accept_inbound_cross_cluster_search_connection)
         """
 
-    def add_tags(self, ARN: str, TagList: List["TagTypeDef"]) -> None:
+    def add_tags(self, *, ARN: str, TagList: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#add_tags)
         """
 
-    def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
+    def associate_package(
+        self, *, PackageID: str, DomainName: str
+    ) -> AssociatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.associate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
-        self, DomainName: str
+        self, *, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#cancel_elasticsearch_service_software_update)
         """
 
@@ -178,7 +180,7 @@ class ElasticsearchServiceClient:
         TagList: List["TagTypeDef"] = None
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_elasticsearch_domain)
         """
 
@@ -190,7 +192,7 @@ class ElasticsearchServiceClient:
         ConnectionAlias: str
     ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_outbound_cross_cluster_search_connection)
         """
 
@@ -203,43 +205,43 @@ class ElasticsearchServiceClient:
         PackageDescription: str = None
     ) -> CreatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.create_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_package)
         """
 
     def delete_elasticsearch_domain(
-        self, DomainName: str
+        self, *, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_service_role)
         """
 
     def delete_inbound_cross_cluster_search_connection(
-        self, CrossClusterSearchConnectionId: str
+        self, *, CrossClusterSearchConnectionId: str
     ) -> DeleteInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_inbound_cross_cluster_search_connection)
         """
 
     def delete_outbound_cross_cluster_search_connection(
-        self, CrossClusterSearchConnectionId: str
+        self, *, CrossClusterSearchConnectionId: str
     ) -> DeleteOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_outbound_cross_cluster_search_connection)
         """
 
-    def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
+    def delete_package(self, *, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_package)
         """
 
@@ -247,31 +249,31 @@ class ElasticsearchServiceClient:
         self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_domain_auto_tunes)
         """
 
     def describe_elasticsearch_domain(
-        self, DomainName: str
+        self, *, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
-        self, DomainName: str
+        self, *, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
-        self, DomainNames: List[str]
+        self, *, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domains)
         """
 
@@ -283,7 +285,7 @@ class ElasticsearchServiceClient:
         DomainName: str = None
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_instance_type_limits)
         """
 
@@ -291,7 +293,7 @@ class ElasticsearchServiceClient:
         self, *, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_inbound_cross_cluster_search_connections)
         """
 
@@ -299,7 +301,7 @@ class ElasticsearchServiceClient:
         self, *, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_outbound_cross_cluster_search_connections)
         """
 
@@ -311,7 +313,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None
     ) -> DescribePackagesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_packages)
         """
 
@@ -323,7 +325,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instance_offerings)
         """
 
@@ -335,15 +337,15 @@ class ElasticsearchServiceClient:
         NextToken: str = None
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instances)
         """
 
     def dissociate_package(
-        self, PackageID: str, DomainName: str
+        self, *, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#dissociate_package)
         """
 
@@ -355,15 +357,15 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
-        self, DomainName: str = None
+        self, *, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_compatible_elasticsearch_versions)
         """
 
@@ -371,7 +373,7 @@ class ElasticsearchServiceClient:
         self, *, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_package_version_history)
         """
 
@@ -379,19 +381,19 @@ class ElasticsearchServiceClient:
         self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_history)
         """
 
-    def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
+    def get_upgrade_status(self, *, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domain_names)
         """
 
@@ -399,7 +401,7 @@ class ElasticsearchServiceClient:
         self, *, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domains_for_package)
         """
 
@@ -412,15 +414,15 @@ class ElasticsearchServiceClient:
         NextToken: str = None
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
-        self, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_versions)
         """
 
@@ -428,13 +430,13 @@ class ElasticsearchServiceClient:
         self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_packages_for_domain)
         """
 
-    def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
+    def list_tags(self, *, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_tags)
         """
 
@@ -446,29 +448,29 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#purchase_reserved_elasticsearch_instance_offering)
         """
 
     def reject_inbound_cross_cluster_search_connection(
-        self, CrossClusterSearchConnectionId: str
+        self, *, CrossClusterSearchConnectionId: str
     ) -> RejectInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#reject_inbound_cross_cluster_search_connection)
         """
 
-    def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
+    def remove_tags(self, *, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
-        self, DomainName: str
+        self, *, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#start_elasticsearch_service_software_update)
         """
 
@@ -491,7 +493,7 @@ class ElasticsearchServiceClient:
         AutoTuneOptions: "AutoTuneOptionsTypeDef" = None
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_elasticsearch_domain_config)
         """
 
@@ -504,7 +506,7 @@ class ElasticsearchServiceClient:
         CommitMessage: str = None
     ) -> UpdatePackageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.update_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_package)
         """
 
@@ -512,7 +514,7 @@ class ElasticsearchServiceClient:
         self, *, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#upgrade_elasticsearch_domain)
         """
 
@@ -521,7 +523,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstanceofferingspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstanceofferingspaginator)
         """
 
     @overload
@@ -529,7 +531,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstancespaginator)
         """
 
     @overload
@@ -537,7 +539,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#getupgradehistorypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#getupgradehistorypaginator)
         """
 
     @overload
@@ -545,7 +547,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchinstancetypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchinstancetypespaginator)
         """
 
     @overload
@@ -553,5 +555,5 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchversionspaginator)
         """
